package zabi.uniud.cggwrapper.ui;

import java.awt.BorderLayout;
import java.awt.Dimension;
import java.awt.Toolkit;

import javax.swing.Box;
import javax.swing.BoxLayout;
import javax.swing.ButtonGroup;
import javax.swing.JButton;
import javax.swing.JCheckBox;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JRadioButton;

import zabi.uniud.cggwrapper.Config;
import zabi.uniud.cggwrapper.launch.AppLaunch;

public class ConfigFrame extends JFrame {
	
//	private static final Font font = new Font("Verdana", Font.PLAIN, 12);
	
	private JCheckBox useAA = new JCheckBox("Enable AntiAliasing for fonts (Fixes some visual artifacts on some DEs like KDE)", true);
	private JCheckBox useGL = new JCheckBox("Enable openGL pipeline (Reduces lag, but might cause rendering issues)", true);
	private JCheckBox skipSplash = new JCheckBox("Skip splash screen (Prevents a crash on some systems)", false);
	private JCheckBox configure = new JCheckBox("Select these options automatically on startup", false);
	private JRadioButton toFile = new JRadioButton("Save the config on a file (Must be in the same directory as this file) (Recommended)", true);
	private JRadioButton toReg = new JRadioButton("Save the config to the system registry (Not recommended)", false);
	private JLabel resetInstructions = new JLabel("This screen will be shown on next launch too");
	private JButton avvia = new JButton("Start ChronoGeoGraph");
	private JPanel content = new JPanel();

	private ButtonGroup radio = new ButtonGroup();
	
	public ConfigFrame(String[] args) {
		this.setSize(700, 400);
		this.setTitle("ChronoGeoGraph Launcher by Simone Zanin");
		this.setLayout(new BorderLayout(5, 5));
//		this.setFont(font);
		this.setResizable(false);
		this.setDefaultCloseOperation(JFrame.DISPOSE_ON_CLOSE);
		toFile.setEnabled(false);
		toReg.setEnabled(false);
		configure.addChangeListener(e -> {
			toFile.setEnabled(configure.isSelected());
			toReg.setEnabled(configure.isSelected());
			if (!configure.isSelected()) {
				resetInstructions.setText("This screen will be shown on next launch too");
			}
		});
		
		toFile.addChangeListener(e -> {
			if (toFile.isSelected()) {
				resetInstructions.setText("Delete the '.cggsettings' file to show this again (or use '--reset')");
			} else {
				resetInstructions.setText("Start this app with the '--reset' parameter to show this again");
			}
		});
		content.setAlignmentX(0);
		content.setLayout(new BoxLayout(content, BoxLayout.Y_AXIS));
		content.add(useAA);
		content.add(useGL);
		content.add(skipSplash);
		content.add(Box.createVerticalGlue());
		content.add(Box.createVerticalStrut(20));
		content.add(configure);
		content.add(toFile);
		content.add(toReg);
		content.add(resetInstructions);
		content.add(Box.createVerticalStrut(20));
		content.add(Box.createVerticalGlue());
		content.add(avvia);
		radio.add(toFile);
		radio.add(toReg);
		avvia.addActionListener(event -> {
			Config cf = new Config();
			cf.useAA = useAA.isSelected();
			cf.useGL = useGL.isSelected();
			cf.splash = skipSplash.isSelected();
			if (configure.isSelected()) {
				Config.delete();
				if (toFile.isSelected()) {
					Config.writeToFile(cf);
				} else {
					Config.writeToRegistry(cf);
				}
			}
			this.dispose();
			AppLaunch.runNewInstance(cf, args);
		});
		this.add(content, BorderLayout.CENTER);
		this.add(Box.createHorizontalStrut(10), BorderLayout.WEST);
		this.add(Box.createHorizontalStrut(10), BorderLayout.EAST);
		this.add(Box.createVerticalStrut(10), BorderLayout.NORTH);
		this.add(Box.createVerticalStrut(10), BorderLayout.SOUTH);
		this.pack();
		Dimension screen = Toolkit.getDefaultToolkit().getScreenSize();
		this.setBounds((screen.width - this.getWidth())/2, (screen.height - this.getHeight())/2, this.getWidth(), this.getHeight() + 10);
		this.setVisible(true);
	}
	
}
